==> vmaid-1.8.2.tar.gz: vmaid-1.8.2/src/general.h <==
/*
    Video maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __GENERAL_H__
#define __GENERAL_H__


#include "vmaid.h"


/*	åȤä
	vmaid,ɥ													*/
void hide_caret(VmaidWindow *vmaid);


/*	åȤ
	 vmaid,ɥ
	cursor,ŤåȰ												*/
void draw_caret(VmaidWindow *vmaid,VmaidCursor *cursor);


/*	˥塼ꤹ
	vmaid,ɥ													*/
void set_menu_bar(VmaidWindow *vmaid);


/*	ϰϤ褹
	 vmaid,ɥ
	cursor,ŤåȰ
	select,Ť򳫻ϰ
	   top,Ťκɸ														*/
void clear_sel(VmaidWindow *vmaid,
							VmaidCursor *cursor,VmaidCursor *select,gint top);


/*	ꥹȤ
	  d,ꥹȤƬ
	RET,ꥹȤο													*/
gint delete_list(VmaidHistory **d);


/*	Խ
	vmaid,ɥ
	 kind,TRUE:redo,FALSE:undo												*/
void history_operation(VmaidWindow *vmaid,gboolean kind);


/*	ե¸䤤碌
	vmaid,ɥ
	  RET,TRUE:եĤ,FALSE:եĤʤ					*/
gboolean prompt_close(VmaidWindow *vmaid);


/*	ե졼
	 vmaid,ɥ
	stream,ͭʥȥ꡼
	   RET,ե졼													*/
gint get_max_frame(VmaidWindow *vmaid,gint stream);


#endif

==> vmaid-1.8.6.tar.gz: vmaid-1.8.6/src/general.h <==
/*
    Video maid
    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __GENERAL_H__
#define __GENERAL_H__


#include "vmaid.h"


/*	åȤä
	vmaid,ɥ													*/
void hide_caret(VmaidWindow *vmaid);


/*	åȤ
	 vmaid,ɥ
	cursor,ŤåȰ												*/
void draw_caret(VmaidWindow *vmaid,VmaidCursor *cursor);


/*	˥塼ꤹ
	vmaid,ɥ													*/
void set_menu_bar(VmaidWindow *vmaid);


/*	ϰϤ褹
	 vmaid,ɥ
	cursor,ŤåȰ
	select,Ť򳫻ϰ
	   top,Ťκɸ														*/
void clear_sel(VmaidWindow *vmaid,
					VmaidCursor *cursor,VmaidCursor *select,const gint top);


/*	ꥹȤ
	  d,ꥹȤƬ
	RET,ꥹȤο													*/
gint delete_list(VmaidHistory **d);


/*	Խ
	vmaid,ɥ
	 kind,TRUE:redo,FALSE:undo												*/
void history_operation(VmaidWindow *vmaid,const gboolean kind);


/*	ե¸䤤碌
	vmaid,ɥ
	  RET,TRUE:եĤ,FALSE:եĤʤ					*/
gboolean prompt_close(VmaidWindow *vmaid);


/*	ե졼
	 vmaid,ɥ
	stream,ͭʥȥ꡼
	   RET,ե졼													*/
gint get_max_frame(VmaidWindow *vmaid,const gint stream);


#endif
